@@ -39,6 +39,7 @@ if os.environ.get('USE_TWISTED', False):
     from autobahn.twisted.websocket import WebSocketServerFactory
     from autobahn.twisted.websocket import WebSocketClientProtocol
     from autobahn.twisted.websocket import WebSocketClientFactory
+    from autobahn.websocket.compress_deflate import PerMessageDeflate
 
     from mock import MagicMock, patch
     from txaio.testutil import replace_loop
@@ -82,6 +83,47 @@ if os.environ.get('USE_TWISTED', False):
 
     mock_handshake_server = b'HTTP/1.1 101 Switching Protocols\r\nServer: AutobahnPython/0.10.2\r\nX-Powered-By: AutobahnPython/0.10.2\r\nUpgrade: WebSocket\r\nConnection: Upgrade\r\nSec-WebSocket-Protocol: wamp.2.json\r\nSec-WebSocket-Accept: QIatSt9QkZPyS4QQfdufO8TgkL0=\r\n\r\n\x81~\x02\x19[1,"crossbar",{"roles":{"subscriber":{"features":{"publisher_identification":true,"pattern_based_subscription":true,"subscription_revocation":true}},"publisher":{"features":{"publisher_identification":true,"publisher_exclusion":true,"subscriber_blackwhite_listing":true}},"caller":{"features":{"caller_identification":true,"progressive_call_results":true}},"callee":{"features":{"progressive_call_results":true,"pattern_based_registration":true,"registration_revocation":true,"shared_registration":true,"caller_identification":true}}}}]\x18'
 
+    class TestDeflate(unittest.TestCase):
+
+        def test_max_size(self):
+            decoder = PerMessageDeflate(
+                is_server=False,
+                server_no_context_takeover=False,
+                client_no_context_takeover=False,
+                server_max_window_bits=15,
+                client_max_window_bits=15,
+                mem_level=8,
+                max_message_size=10,
+            )
+
+            # 2000 'x' characters compressed
+            compressed_data = b'\xab\xa8\x18\x05\xa3`\x14\x8c\x82Q0\nF\xc1P\x07\x00\xcf@\xa9\xae'
+
+            decoder.start_decompress_message()
+            data = decoder.decompress_message_data(compressed_data)
+
+            # since we set max_message_size, we should only get that
+            # many bytes back.
+            self.assertEqual(data, b"x" * 10)
+
+        def test_no_max_size(self):
+            decoder = PerMessageDeflate(
+                is_server=False,
+                server_no_context_takeover=False,
+                client_no_context_takeover=False,
+                server_max_window_bits=15,
+                client_max_window_bits=15,
+                mem_level=None,
+            )
+
+            # 2000 'x' characters compressed
+            compressed_data = b'\xab\xa8\x18\x05\xa3`\x14\x8c\x82Q0\nF\xc1P\x07\x00\xcf@\xa9\xae'
+
+            decoder.start_decompress_message()
+            data = decoder.decompress_message_data(compressed_data)
+
+            self.assertEqual(data, b"x" * 2000)
+
     class TestClient(unittest.TestCase):
         def setUp(self):
             self.factory = WebSocketClientFactory(protocols=['wamp.2.json'])
